@@ -1,21 +1,7 @@
 /*
- * Copyright 2020 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2020 Kai Uwe Broulik <kde@broulik.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "chargethresholdhelper.h"
@@ -63,8 +49,8 @@ static QStringList getBatteries()
             continue; // Not a battery, skip
         }
 
-        if (!psuDir.exists(s_chargeStartThreshold) && !psuDir.exists(s_oldChargeStartThreshold)
-            && !psuDir.exists(s_chargeEndThreshold) && !psuDir.exists(s_oldChargeStopThreshold)) {
+        if (!psuDir.exists(s_chargeStartThreshold) && !psuDir.exists(s_oldChargeStartThreshold) && !psuDir.exists(s_chargeEndThreshold)
+            && !psuDir.exists(s_oldChargeStopThreshold)) {
             continue; // No charge thresholds, skip
         }
 
@@ -74,9 +60,9 @@ static QStringList getBatteries()
     return batteries;
 }
 
-static QVector<int> getThresholds(const QString &which)
+static QList<int> getThresholds(const QString &which)
 {
-    QVector<int> thresholds;
+    QList<int> thresholds;
 
     const QStringList batteries = getBatteries();
     for (const QString &battery : batteries) {
@@ -152,7 +138,7 @@ ActionReply ChargeThresholdHelper::getthreshold(const QVariantMap &args)
     ActionReply reply;
     reply.setData({
         {QStringLiteral("chargeStartThreshold"), startThreshold},
-        {QStringLiteral("chargeStopThreshold"), stopThreshold}
+        {QStringLiteral("chargeStopThreshold"), stopThreshold},
     });
     return reply;
 }
@@ -167,10 +153,8 @@ ActionReply ChargeThresholdHelper::setthreshold(const QVariantMap &args)
     const int stopThreshold = args.value(QStringLiteral("chargeStopThreshold"), -1).toInt(&hasStopThreshold);
     hasStopThreshold &= stopThreshold != -1;
 
-    if ((hasStartThreshold && (startThreshold < 0|| startThreshold > 100))
-            || (hasStopThreshold && (stopThreshold < 0 || stopThreshold > 100))
-            || (hasStartThreshold && hasStopThreshold && startThreshold > stopThreshold)
-            || (!hasStartThreshold && !hasStopThreshold)) {
+    if ((hasStartThreshold && (startThreshold < 0 || startThreshold > 100)) || (hasStopThreshold && (stopThreshold < 0 || stopThreshold > 100))
+        || (hasStartThreshold && hasStopThreshold && startThreshold > stopThreshold) || (!hasStartThreshold && !hasStopThreshold)) {
         auto reply = ActionReply::HelperErrorReply(); // is there an "invalid arguments" error?
         reply.setErrorDescription(QStringLiteral("Invalid thresholds provided"));
         return reply;
@@ -192,3 +176,5 @@ ActionReply ChargeThresholdHelper::setthreshold(const QVariantMap &args)
 }
 
 KAUTH_HELPER_MAIN("org.kde.powerdevil.chargethresholdhelper", ChargeThresholdHelper)
+
+#include "moc_chargethresholdhelper.cpp"
